complete -c bcachefs -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_use_subcommand" -f -a "list" -d 'List filesystem metadata in textual form'
complete -c bcachefs -n "__fish_use_subcommand" -f -a "mount" -d 'Mount a bcachefs filesystem by its UUID'
complete -c bcachefs -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c bcachefs -n "__fish_use_subcommand" -f -a "subvolume" -d 'Subvolumes-related commands'
complete -c bcachefs -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s b -l btree -d 'Btree to list from' -r
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s l -l level -d 'Btree depth to descend to (0 == leaves)' -r
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s s -l start -d 'Start position to list from' -r
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s e -l end -d 'End position' -r
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s m -l mode -r -f -a "{keys	'',formats	'',nodes	'',nodes-ondisk	''}"
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s c -l colorize -d 'Force color on/off. Default: autodetect tty' -r -f -a "{true	'',false	''}"
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s f -l fsck -d 'Check (fsck) the filesystem first'
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s v -l verbose -d 'Verbose mode'
complete -c bcachefs -n "__fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s f -l passphrase-file -d 'Path to passphrase/key file' -r -F
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s k -l key_location -d 'Password policy to use in case of encrypted filesystem.' -r -f -a "{none	'',fail	'',wait	'',ask	''}"
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s o -d 'Mount options' -r
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s c -l colorize -d 'Force color on/off. Autodetect tty is used to define default:' -r -f -a "{true	'',false	''}"
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s v -l verbose -d 'Verbose mode'
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_seen_subcommand_from mount" -s V -l version -d 'Print version'
complete -c bcachefs -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "create"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "snapshot"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from snapshot" -s r -l read-only -d 'Make snapshot read only'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from snapshot" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "create"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "delete"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "snapshot"
complete -c bcachefs -n "__fish_seen_subcommand_from subvolume; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from mount; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List filesystem metadata in textual form'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from mount; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from help" -f -a "mount" -d 'Mount a bcachefs filesystem by its UUID'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from mount; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completions'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from mount; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from help" -f -a "subvolume" -d 'Subvolumes-related commands'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from mount; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot" -f -a "create"
complete -c bcachefs -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot" -f -a "delete"
complete -c bcachefs -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from subvolume; and not __fish_seen_subcommand_from create; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from snapshot" -f -a "snapshot"
